summaryrefslogtreecommitdiffstats
path: root/src/prefpreview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/prefpreview.cpp')
-rw-r--r--src/prefpreview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/prefpreview.cpp b/src/prefpreview.cpp
index cb2fad6..872d86e 100644
--- a/src/prefpreview.cpp
+++ b/src/prefpreview.cpp
@@ -22,11 +22,11 @@
#include <tqwhatsthis.h>
/*
* Constructs a prefPreview as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-prefPreview::prefPreview( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+prefPreview::prefPreview( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "prefPreview" );
@@ -22,11 +22,11 @@
#include <tqwhatsthis.h>
/*
- * Constructs a prefPreview as a child of 'tqparent', with the
+ * Constructs a prefPreview as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/